@@ -3,7 +3,7 @@ package Markdent::Dialect::Theory::BlockParser;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use List::AllUtils qw( insert_after_string sum );
 use Markdent::Event::StartTable;
@@ -102,11 +102,12 @@ sub _match_table {
                                   $HeaderMarkerLine?
                                   ($TableHeader+)?
                                   (
+                                    $TableRow
                                     (?:
                                       $TableRow
                                       |
                                       $EmptyLine
-                                    )+
+                                    )*
                                   )
                                   $HeaderMarkerLine?
                                   $TableCaption?
@@ -461,7 +462,7 @@ Dave Rolsky, E<lt>autarch@urth.orgE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Dave Rolsky, All Rights Reserved.
+Copyright 2009-2010 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
